==> postchain-client-0.1.0.tgz: package/src/gtxclient.js <==
"use strict";
var gtxTool = require('./gtx');
var secp256k1 = require('secp256k1');
var util = require('postchain-common').util;

module.exports.createClient = function (restApiClient, functionNames) {
    functionNames.push('message');

    var client = {
        newRequest: function (signers) {
            var newGtx = gtxTool.emptyGtx();
            signers.forEach(signer => gtxTool.addSignerToGtx(signer, newGtx));

            var req = {
                gtx: newGtx,

                sign: function (privKey) {
                    var pubKey = secp256k1.publicKeyCreate(privKey);
                    gtxTool.sign(privKey, pubKey, this.gtx);
                },

                getBufferToSign: function () {
                    return gtxTool.getBufferToSign(this.gtx);
                },

                addSignature: function (pubKey, signature) {
                    gtxTool.addSignature(pubKey, signature, this.gtx);
                },

                send: function (callback) {
                    var gtxBytes = gtxTool.serialize(this.gtx);
                    restApiClient.postTransaction(gtxBytes, callback);
                    this.gtx = null;
                }
            };

            functionNames.forEach((functionName) => {
                req[functionName] = function (...args) {
                    gtxTool.addCallToGtx(functionName, args, this.gtx);
                }
            });
            return req;
        },

        /*
        This function is only used for the messaging feature. It's a convenience function that
        uses POST /query under the hood.
         */
        pollMessages: function (recipient, fromMessageId, maxHits, resultCallback) {
            let queryObject = {type: 'getGtxMessages',
                recipient: recipient.toString('hex'),
                sinceMessageId: fromMessageId == null ? null : fromMessageId.toString('hex'),
                maxHits: maxHits};
            restApiClient.query(queryObject, (error, messages) => {
                if (error) {
                    resultCallback(error);
                    return;
                }
                var result = messages.map((gtxAndIndex) => {
                    console.log("gtxData: " + JSON.stringify(gtxAndIndex.txData));
                    console.log("isBuffer: " + Buffer.isBuffer(gtxAndIndex.txData));
                    var txData = Buffer.from(gtxAndIndex.txData, 'hex');
                    var gtx = gtxTool.deserialize(txData);
                    var call = gtx.calls[gtxAndIndex.callIndex];
                    // call args: recipients, 'testtype', messageBytes
                    return {recipients: call.args[0], type: call.args[1],
                        message: call.args[2], messageId: util.hash256(txData)};
                });
                resultCallback(null, result);
            });
        },

        query: function (queryObject, resultCallback) {
            restApiClient.query(queryObject, resultCallback);
        }
    };

    return client;
};

==> postchain-client-0.1.2.tgz: package/src/gtxclient.js <==
"use strict";
var gtxTool = require('./gtx');
var secp256k1 = require('secp256k1');
var util = require('postchain-common').util;

module.exports.createClient = function (restApiClient, functionNames) {
    functionNames.push('message');

    var client = {
        newRequest: function (signers) {
            var newGtx = gtxTool.emptyGtx();
            signers.forEach(signer => gtxTool.addSignerToGtx(signer, newGtx));

            var req = {
                gtx: newGtx,

                sign: function (privKey, pubKey) {
                    let pub = pubKey;
                    if (!pub) {
                        pub = secp256k1.publicKeyCreate(privKey);
                    }
                    gtxTool.sign(privKey, pub, this.gtx);
                },

                getBufferToSign: function () {
                    return gtxTool.getBufferToSign(this.gtx);
                },

                addSignature: function (pubKey, signature) {
                    gtxTool.addSignature(pubKey, signature, this.gtx);
                },

                send: function (callback) {
                    var gtxBytes = gtxTool.serialize(this.gtx);
                    restApiClient.postTransaction(gtxBytes, callback);
                    this.gtx = null;
                }
            };

            functionNames.forEach((functionName) => {
                req[functionName] = function (...args) {
                    gtxTool.addCallToGtx(functionName, args, this.gtx);
                }
            });
            return req;
        },

        /*
        This function is only used for the messaging feature. It's a convenience function that
        uses POST /query under the hood.
         */
        pollMessages: function (recipient, fromMessageId, maxHits, resultCallback) {
            let queryObject = {type: 'getGtxMessages',
                recipient: recipient.toString('hex'),
                sinceMessageId: fromMessageId == null ? null : fromMessageId.toString('hex'),
                maxHits: maxHits};
            restApiClient.query(queryObject, (error, messages) => {
                if (error) {
                    resultCallback(error);
                    return;
                }
                var result = messages.map((gtxAndIndex) => {
                    console.log("gtxData: " + JSON.stringify(gtxAndIndex.txData));
                    console.log("isBuffer: " + Buffer.isBuffer(gtxAndIndex.txData));
                    var txData = Buffer.from(gtxAndIndex.txData, 'hex');
                    var gtx = gtxTool.deserialize(txData);
                    var call = gtx.calls[gtxAndIndex.callIndex];
                    // call args: recipients, 'testtype', messageBytes
                    return {recipients: call.args[0], type: call.args[1],
                        message: call.args[2], messageId: util.hash256(txData)};
                });
                resultCallback(null, result);
            });
        },

        query: function (queryObject, resultCallback) {
            restApiClient.query(queryObject, resultCallback);
        }
    };

    return client;
};
